aboutsummaryrefslogtreecommitdiffhomepage
path: root/src/gpu/gl/GrGLProgramDataManager.h
diff options
context:
space:
mode:
authorGravatar Brian Salomon <bsalomon@google.com>2016-11-21 13:41:08 -0500
committerGravatar Skia Commit-Bot <skia-commit-bot@chromium.org>2016-11-21 19:13:43 +0000
commit99938a8ef24e2dd5b39f78638742e9b50ab6d9bf (patch)
treee3842210db20a4574e9cec37ae7f049aaff27b65 /src/gpu/gl/GrGLProgramDataManager.h
parentd728f0c1a94fe926b59d8ebc9ae174019ccd3606 (diff)
Merge GrGLSLShaderVar and GrShaderVar
GOLD_TRYBOT_URL= https://gold.skia.org/search?issue=5087 Change-Id: Ib8943a1da1ea495554feaf5b0992b94fbb9539ab Reviewed-on: https://skia-review.googlesource.com/5087 Commit-Queue: Brian Salomon <bsalomon@google.com> Reviewed-by: Ethan Nicholas <ethannicholas@google.com>
Diffstat (limited to 'src/gpu/gl/GrGLProgramDataManager.h')
-rw-r--r--src/gpu/gl/GrGLProgramDataManager.h12
1 files changed, 5 insertions, 7 deletions
diff --git a/src/gpu/gl/GrGLProgramDataManager.h b/src/gpu/gl/GrGLProgramDataManager.h
index fa1456dcc7..0ef902c10b 100644
--- a/src/gpu/gl/GrGLProgramDataManager.h
+++ b/src/gpu/gl/GrGLProgramDataManager.h
@@ -8,11 +8,10 @@
#ifndef GrGLProgramDataManager_DEFINED
#define GrGLProgramDataManager_DEFINED
-#include "glsl/GrGLSLProgramDataManager.h"
-
#include "GrAllocator.h"
+#include "GrShaderVar.h"
#include "gl/GrGLTypes.h"
-#include "glsl/GrGLSLShaderVar.h"
+#include "glsl/GrGLSLProgramDataManager.h"
#include "SkTArray.h"
@@ -27,18 +26,17 @@ class GrGLProgram;
class GrGLProgramDataManager : public GrGLSLProgramDataManager {
public:
struct UniformInfo {
- GrGLSLShaderVar fVariable;
+ GrShaderVar fVariable;
uint32_t fVisibility;
GrGLint fLocation;
};
struct VaryingInfo {
- GrGLSLShaderVar fVariable;
+ GrShaderVar fVariable;
GrGLint fLocation;
};
-
- // This uses an allocator rather than array so that the GrGLSLShaderVars don't move in memory
+ // This uses an allocator rather than array so that the GrShaderVars don't move in memory
// after they are inserted. Users of GrGLShaderBuilder get refs to the vars and ptrs to their
// name strings. Otherwise, we'd have to hand out copies.
typedef GrTAllocator<UniformInfo> UniformInfoArray;